export { default as App } from './components/App';
export { Chat } from './components/internal/chat';
export { StatusIndicator } from './components/internal/header';
export { Schema } from './components/internal/schema';
export {
	useWorkbench,
	WorkbenchProvider,
	type GetAuthHeaders,
} from './components/internal/workbench-provider';
export type { WorkbenchInstance } from './types';
export type { ConnectionStatus, WorkbenchMessage } from './types/config';
export { createWorkbench } from './workbench';
