type PanelSizes = Record<string, number[]>;
type ResizableProviderProps = {
    children: React.ReactNode;
    storageKey?: string;
};
type ResizableProviderState = {
    panelSizes: PanelSizes;
    setPanelSizes: (groupId: string, sizes: number[]) => void;
    getPanelSizes: (groupId: string) => number[] | undefined;
    resetPanelSizes: (groupId?: string) => void;
};
export declare function ResizableProvider({ children, storageKey, ...props }: ResizableProviderProps): import("react/jsx-runtime").JSX.Element;
export declare const useResizable: () => ResizableProviderState;
export {};
//# sourceMappingURL=resizable-provider.d.ts.map