export interface UseWorkbenchWebsocketOptions {
    apiKey?: string;
    baseUrl?: string;
    enabled?: boolean;
    headers?: Record<string, string>;
    onAlive?: () => void;
    onConnect?: () => void;
    onReconnect?: () => void;
    onRestarting?: () => void;
}
export interface UseWorkbenchWebsocketResult {
    connected: boolean;
    error: Error | null;
}
export declare function useWorkbenchWebsocket(options?: UseWorkbenchWebsocketOptions): UseWorkbenchWebsocketResult;
//# sourceMappingURL=useWorkbenchWebsocket.d.ts.map