import type { AgentSchemaData } from '../../hooks/useAgentSchemas';
export interface InputSectionProps {
    agents: Record<string, AgentSchemaData>;
    className?: string;
    clearAgentState?: (agentId: string) => Promise<void>;
    isLoading: boolean;
    isSchemaOpen?: boolean;
    onChange: (value: string) => void;
    onSchemaToggle?: () => void;
    onSubmit: () => void | Promise<void>;
    selectedAgent: string;
    setSelectedAgent: (agentId: string) => void;
    value: string;
}
export declare function InputSection({ agents, className, clearAgentState, isLoading, isSchemaOpen, onChange, onSchemaToggle, onSubmit, selectedAgent, setSelectedAgent, value, }: InputSectionProps): import("react/jsx-runtime").JSX.Element;
//# sourceMappingURL=input-section.d.ts.map